@@ -102,7 +102,7 @@ class Transfer:
     __RESIF_NODES = (
         "DASE",
         "IPGP",
-        "OBS-INSU",
+        "MARINE",
         "OMIV",
         "RAP",
         "RLBP",
